@@ -1,11 +1,12 @@
-from captur_ml_sdk.dtypes.generics import Image, Meta
+from captur_ml_sdk.dtypes.generics import Image
 from pydantic import BaseModel
 from typing import List, Optional, Dict
 
 class EvalEventData(BaseModel):
     request_id: str
     webhooks: str
-    images: List[Image]
+    images: Optional[List[Image]]
+    evaluation_file: Optional[str]
     model_name: str
     model_id: str
     model_type: str
