@@ -1,5 +1,5 @@
 from pydantic import BaseModel
-from typing import Optional
+from typing import Optional, Dict
 
 
 class RunEventData(BaseModel):
@@ -9,6 +9,7 @@ class RunEventData(BaseModel):
     training_display_name: str
     request_id: str
     request_type: str
+    mapping: Optional[Dict[str, Dict[str, str]]]
     webhooks: str
     budget_milli_node_hours: int
     percentage_images_included: Optional[float]
